==> swi-prolog-5.6.59p2.tgz: lib/swipl-5.6.59/xpce-6.6.58/prolog/lib/INDEX.pl <==
/*  $Id$

    Creator: make/0

    Purpose: Provide index for autoload
*/

index((ensure_x_server), 2, 'Xserver', 'Xserver').
index((side_pattern), 3, area, area).
index((draw_begin_shape), 3, draw_extend, draw_extend).
index((draw_end_shape), 0, draw_extend, draw_extend).
index((dialog), 0, dia_main, edit_dialog).
index((declare_emacs_mode), 2, emacs_extend, emacs_extend).
index((declare_emacs_mode), 3, emacs_extend, emacs_extend).
index((emacs_tag), 3, emacs_tags, emacs_tags).
index((emacs_tag_file), 1, emacs_tags, emacs_tags).
index((emacs_init_tags), 1, emacs_tags, emacs_tags).
index((emacs_complete_tag), 2, emacs_tags, emacs_tags).
index((guitracer), 0, gui_tracer, gui_tracer).
index((noguitracer), 0, gui_tracer, gui_tracer).
index((prolog_break_at), 3, gui_tracer, gui_tracer).
index((gtrace), 0, gui_tracer, gui_tracer).
index((gspy), 1, gui_tracer, gui_tracer).
index((gdebug), 0, gui_tracer, gui_tracer).
index((iso_check_file), 1, isocomp, isocomp).
index((iso_check_directory), 1, isocomp, isocomp).
index((iso_check_application), 1, isocomp, isocomp).
index((show_key_bindings), 1, key_binding, keybinding).
index((make_dialog), 2, pce_make_dialog, make_dialog).
index((new), 2, pce, pce).
index((free), 1, pce, pce).
index((send), 2, pce, pce).
index((send), 3, pce, pce).
index((send), 4, pce, pce).
index((send), 5, pce, pce).
index((send), 6, pce, pce).
index((send), 7, pce, pce).
index((send), 8, pce, pce).
index((send), 9, pce, pce).
index((send), 10, pce, pce).
index((send), 11, pce, pce).
index((send), 12, pce, pce).
index((get), 3, pce, pce).
index((get), 4, pce, pce).
index((get), 5, pce, pce).
index((get), 6, pce, pce).
index((get), 7, pce, pce).
index((get), 8, pce, pce).
index((get), 9, pce, pce).
index((get), 10, pce, pce).
index((get), 11, pce, pce).
index((get), 12, pce, pce).
index((get), 13, pce, pce).
index((send_class), 3, pce, pce).
index((get_class), 4, pce, pce).
index((object), 1, pce, pce).
index((object), 2, pce, pce).
index((pce_global), 2, pce, pce).
index((pce_autoload), 2, pce, pce).
index((pce_autoload_all), 0, pce, pce).
index((pce_term_expansion), 2, pce, pce).
index((pce_compiling), 1, pce, pce).
index((pce_compiling), 2, pce, pce).
index((pce_begin_recording), 1, pce, pce).
index((pce_end_recording), 0, pce, pce).
index((pce_register_class), 1, pce, pce).
index((pce_extended_class), 1, pce, pce).
index((pce_begin_class_definition), 4, pce, pce).
index((pce_prolog_class), 1, pce, pce).
index((pce_prolog_class), 2, pce, pce).
index((pce_catch_error), 2, pce, pce).
index((pce_open), 3, pce, pce).
index((pce_dispatch), 1, pce, pce).
index((pce_end_dispatch), 0, pce, pce).
index((pce_call), 1, pce, pce).
index((in_pce_thread), 1, pce, pce).
index((pce_welcome), 0, pce, pce).
index((generate_cpp_class_header_file), 0, pce_cpp_header, 'pce_c++_headers').
index((pce_make_library_index), 1, pce_class_index, pce_class_index).
index((pce_update_library_index), 0, pce_class_index, pce_class_index).
index((register_config), 1, pce_config, pce_config).
index((register_config_type), 2, pce_config, pce_config).
index((get_config), 2, pce_config, pce_config).
index((set_config), 2, pce_config, pce_config).
index((add_config), 2, pce_config, pce_config).
index((del_config), 2, pce_config, pce_config).
index((edit_config), 1, pce_config, pce_config).
index((save_config), 1, pce_config, pce_config).
index((load_config), 1, pce_config, pce_config).
index((ensure_loaded_config), 1, pce_config, pce_config).
index((config_term_to_object), 2, pce_config, pce_config).
index((config_term_to_object), 3, pce_config, pce_config).
index((config_attributes), 2, pce_config, pce_config).
index((current_config_type), 3, pce_config, pce_config).
index((generate_cpp_class_header_file), 0, pce_cpp_header, pce_cxx_headers).
index((debugpce), 0, pce_debug, pce_debug).
index((debugpce), 1, pce_debug, pce_debug).
index((nodebugpce), 0, pce_debug, pce_debug).
index((nodebugpce), 1, pce_debug, pce_debug).
index((tracepce), 1, pce_debug, pce_debug).
index((notracepce), 1, pce_debug, pce_debug).
index((spypce), 1, pce_debug, pce_debug).
index((nospypce), 1, pce_debug, pce_debug).
index((checkpce), 0, pce_debug, pce_debug).
index((show_slots), 1, pce_debug, pce_debug).
index((pcerefer), 1, pce_debug, pce_debug).
index((pcerefer), 2, pce_debug, pce_debug).
index((pce_global_objects), 1, pce_debug, pce_debug).
index((pcedemo), 0, pce_demo, pce_demo).
index((editpce), 1, pce_edit, pce_edit).
index((emacs), 0, start_emacs, pce_emacs).
index((emacs), 1, start_emacs, pce_emacs).
index((start_emacs), 0, start_emacs, pce_emacs).
index((emacs_server), 0, start_emacs, pce_emacs).
index((emacs_toplevel), 0, start_emacs, pce_emacs).
index((grapher), 1, pce_grapher, pce_grapher).
index((grapher), 2, pce_grapher, pce_grapher).
index((pce_help_file), 2, pce_help_file, pce_help_file).
index((pce_help), 2, pce_help_file, pce_help_file).
index((pce_image_directory), 1, pce_image, pce_image).
index((pce_load_cxx), 1, pce_load_cxx, pce_loadcxx).
index((pce_loop), 2, pce_main, pce_main).
index((pce_loop), 1, pce_main, pce_main).
index((pce_main_loop), 1, pce_main, pce_main).
index((dispatch_for_frames), 1, pce_main, pce_main).
index((manpce), 0, pce_manual, pce_manual).
index((manpce), 1, pce_manual, pce_manual).
index((pce_to_method), 2, pce_meta, pce_meta).
index((isa_class), 2, pce_meta, pce_meta).
index((current_class), 2, pce_meta, pce_meta).
index((to_class_name), 2, pce_meta, pce_meta).
index((pce_library_class), 4, pce_meta, pce_meta).
index((implements), 2, pce_meta, pce_meta).
index((implements), 3, pce_meta, pce_meta).
index((pce_to_pl_type), 2, pce_meta, pce_meta).
index((type_accepts_function), 1, pce_meta, pce_meta).
index((postscript), 2, pce_postscript, pce_postscript).
index((progress_checklist), 3, pce_progress, pce_progress).
index((xref_source), 1, pce_prolog_xref, pce_prolog_xref).
index((xref_called), 3, pce_prolog_xref, pce_prolog_xref).
index((xref_defined), 3, pce_prolog_xref, pce_prolog_xref).
index((xref_definition_line), 2, pce_prolog_xref, pce_prolog_xref).
index((xref_exported), 2, pce_prolog_xref, pce_prolog_xref).
index((xref_module), 2, pce_prolog_xref, pce_prolog_xref).
index((xref_op), 2, pce_prolog_xref, pce_prolog_xref).
index((xref_clean), 1, pce_prolog_xref, pce_prolog_xref).
index((xref_current_source), 1, pce_prolog_xref, pce_prolog_xref).
index((xref_done), 2, pce_prolog_xref, pce_prolog_xref).
index((xref_built_in), 1, pce_prolog_xref, pce_prolog_xref).
index((xref_expand), 2, pce_prolog_xref, pce_prolog_xref).
index((xref_source_file), 3, pce_prolog_xref, pce_prolog_xref).
index((xref_source_file), 4, pce_prolog_xref, pce_prolog_xref).
index((xref_public_list), 4, pce_prolog_xref, pce_prolog_xref).
index((xref_meta), 2, pce_prolog_xref, pce_prolog_xref).
index((xref_hook), 1, pce_prolog_xref, pce_prolog_xref).
index((xref_used_class), 2, pce_prolog_xref, pce_prolog_xref).
index((xref_defined_class), 3, pce_prolog_xref, pce_prolog_xref).
index((prompter), 2, pce_prompter, pce_prompter).
index((regex_emacs_to_advanced), 2, regex_compat, pce_regex_compat).
index((regex_convert_file), 1, regex_compat, pce_regex_compat).
index((regex_main), 0, regex_compat, pce_regex_compat).
index((pce_renew), 1, pce_renew, pce_renew).
index((pce_require), 1, pce_require, pce_require).
index((pce_require), 3, pce_require, pce_require).
index((pce_server), 1, pce_server, pce_server).
index((pce_shell_command), 1, pce_shell, pce_shell).
index((use_class_template), 1, pce_class_template, pce_template).
index((use_class_template), 2, pce_class_template, pce_template).
index((pce_define_type), 2, pce_type, pce_type).
index((get_object), 3, pce_util, pce_util).
index((get_object), 4, pce_util, pce_util).
index((get_object), 5, pce_util, pce_util).
index((get_object), 6, pce_util, pce_util).
index((get_object), 7, pce_util, pce_util).
index((get_object), 8, pce_util, pce_util).
index((get_object), 9, pce_util, pce_util).
index((get_object), 10, pce_util, pce_util).
index((get_object), 11, pce_util, pce_util).
index((get_object), 12, pce_util, pce_util).
index((get_object), 13, pce_util, pce_util).
index((send_list), 2, pce_util, pce_util).
index((send_list), 3, pce_util, pce_util).
index((get_chain), 3, pce_util, pce_util).
index((chain_list), 2, pce_util, pce_util).
index((default), 3, pce_util, pce_util).
index((gxref), 0, pce_xref_gui, pce_xref).
index((xref_file_imports), 2, pce_xref_gui, pce_xref).
index((xref_file_exports), 2, pce_xref_gui, pce_xref).
index((pcedraw), 0, pce_draw, pcedraw).
index((pcedraw), 1, pce_draw, pcedraw).
index((save_pcedraw), 1, pce_draw, pcedraw).
index((portray_object), 1, pce_portray_object, portray_object).
index((portray_object), 2, pce_portray_object, portray_object).
index((qcompile_pce), 0, pce_qrecompile, qrecompile).
index((scan_arguments), 2, scan_arguments, scan_arguments).
index((scan_arguments), 3, scan_arguments, scan_arguments).
index((pce_fcompile), 1, sp_fcompile, sp_fcompile).
index((pce_fcompile_boot_files), 0, sp_fcompile, sp_fcompile).
index((pce_fcompile_directory), 1, sp_fcompile, sp_fcompile).
index((pce_frecompile_directory), 1, sp_fcompile, sp_fcompile).
index((pce_fcompile_libraries), 0, sp_fcompile, sp_fcompile).
index((pce_frecompile_libraries), 0, sp_fcompile, sp_fcompile).
index((install_unfocus_hook), 0, stayup_popup, stayup_popup).
index((auto_call), 1, pce_compatibility_layer, swi_compatibility).
index((callable_predicate), 1, pce_compatibility_layer, swi_compatibility).
index((modified_since_last_loaded), 1, pce_compatibility_layer, swi_compatibility).
index((pce_error), 1, pce_compatibility_layer, swi_compatibility).
index((pce_warn), 1, pce_compatibility_layer, swi_compatibility).
index((pce_info), 1, pce_compatibility_layer, swi_compatibility).
index((prolog_help), 0, pui_help, swi_help).
index((prolog_help), 1, pui_help, swi_help).
index((prolog_apropos), 1, pui_help, swi_help).
index((prolog_help_topic), 1, pui_help, swi_help).
index((prolog_explain), 1, pui_help, swi_help).
index((prolog_ide), 1, swi_ide, swi_ide).
index((prolog_edit_preferences), 1, prolog_preferences, swi_preferences).
index((prolog_debug_monitor), 0, pce_debug_monitor, 'swi/pce_debug_monitor').
index((pce_show_profile), 0, pce_profile, 'swi/pce_profile').

==> swi-prolog-5.10.2p0.tgz: lib/swipl-5.10.2/xpce-6.6.66/prolog/lib/INDEX.pl <==
/*  $Id$

    Creator: make/0

    Purpose: Provide index for autoload
*/

index((ensure_x_server), 2, 'Xserver', 'Xserver').
index((side_pattern), 3, area, area).
index((draw_begin_shape), 3, draw_extend, draw_extend).
index((draw_end_shape), 0, draw_extend, draw_extend).
index((dialog), 0, dia_main, edit_dialog).
index((declare_emacs_mode), 2, emacs_extend, emacs_extend).
index((declare_emacs_mode), 3, emacs_extend, emacs_extend).
index((emacs_tag), 3, emacs_tags, emacs_tags).
index((emacs_tag_file), 1, emacs_tags, emacs_tags).
index((emacs_init_tags), 1, emacs_tags, emacs_tags).
index((emacs_complete_tag), 2, emacs_tags, emacs_tags).
index((guitracer), 0, gui_tracer, gui_tracer).
index((noguitracer), 0, gui_tracer, gui_tracer).
index((prolog_break_at), 3, gui_tracer, gui_tracer).
index((gtrace), 0, gui_tracer, gui_tracer).
index((gspy), 1, gui_tracer, gui_tracer).
index((gdebug), 0, gui_tracer, gui_tracer).
index((iso_check_file), 1, isocomp, isocomp).
index((iso_check_directory), 1, isocomp, isocomp).
index((iso_check_application), 1, isocomp, isocomp).
index((show_key_bindings), 1, key_binding, keybinding).
index((make_dialog), 2, pce_make_dialog, make_dialog).
index((new), 2, pce, pce).
index((free), 1, pce, pce).
index((send), 2, pce, pce).
index((send), 3, pce, pce).
index((send), 4, pce, pce).
index((send), 5, pce, pce).
index((send), 6, pce, pce).
index((send), 7, pce, pce).
index((send), 8, pce, pce).
index((get), 3, pce, pce).
index((get), 4, pce, pce).
index((get), 5, pce, pce).
index((get), 6, pce, pce).
index((get), 7, pce, pce).
index((get), 8, pce, pce).
index((send_class), 3, pce, pce).
index((get_class), 4, pce, pce).
index((object), 1, pce, pce).
index((object), 2, pce, pce).
index((pce_global), 2, pce, pce).
index((pce_autoload), 2, pce, pce).
index((pce_autoload_all), 0, pce, pce).
index((pce_term_expansion), 2, pce, pce).
index((pce_compiling), 1, pce, pce).
index((pce_compiling), 2, pce, pce).
index((pce_begin_recording), 1, pce, pce).
index((pce_end_recording), 0, pce, pce).
index((pce_register_class), 1, pce, pce).
index((pce_extended_class), 1, pce, pce).
index((pce_begin_class_definition), 4, pce, pce).
index((pce_prolog_class), 1, pce, pce).
index((pce_prolog_class), 2, pce, pce).
index((pce_catch_error), 2, pce, pce).
index((pce_open), 3, pce, pce).
index((in_pce_thread), 1, pce, pce).
index((set_pce_thread), 0, pce, pce).
index((pce_thread), 1, pce, pce).
index((pce_dispatch), 0, pce, pce).
index((pce_welcome), 0, pce, pce).
index((pce_make_library_index), 1, pce_class_index, pce_class_index).
index((pce_update_library_index), 0, pce_class_index, pce_class_index).
index((register_config), 1, pce_config, pce_config).
index((register_config_type), 2, pce_config, pce_config).
index((get_config), 2, pce_config, pce_config).
index((set_config), 2, pce_config, pce_config).
index((add_config), 2, pce_config, pce_config).
index((del_config), 2, pce_config, pce_config).
index((edit_config), 1, pce_config, pce_config).
index((save_config), 1, pce_config, pce_config).
index((load_config), 1, pce_config, pce_config).
index((ensure_loaded_config), 1, pce_config, pce_config).
index((config_term_to_object), 2, pce_config, pce_config).
index((config_term_to_object), 3, pce_config, pce_config).
index((config_attributes), 2, pce_config, pce_config).
index((current_config_type), 3, pce_config, pce_config).
index((generate_cpp_class_header_file), 0, pce_cpp_header, pce_cxx_headers).
index((debugpce), 0, pce_debug, pce_debug).
index((debugpce), 1, pce_debug, pce_debug).
index((nodebugpce), 0, pce_debug, pce_debug).
index((nodebugpce), 1, pce_debug, pce_debug).
index((tracepce), 1, pce_debug, pce_debug).
index((notracepce), 1, pce_debug, pce_debug).
index((spypce), 1, pce_debug, pce_debug).
index((nospypce), 1, pce_debug, pce_debug).
index((checkpce), 0, pce_debug, pce_debug).
index((show_slots), 1, pce_debug, pce_debug).
index((pcerefer), 1, pce_debug, pce_debug).
index((pcerefer), 2, pce_debug, pce_debug).
index((pce_global_objects), 1, pce_debug, pce_debug).
index((pce_dispatch), 1, pce_dispatch, pce_dispatch).
index((pce_end_dispatch), 0, pce_dispatch, pce_dispatch).
index((pce_call), 1, pce_dispatch, pce_dispatch).
index((editpce), 1, pce_edit, pce_edit).
index((emacs), 0, start_emacs, pce_emacs).
index((emacs), 1, start_emacs, pce_emacs).
index((start_emacs), 0, start_emacs, pce_emacs).
index((emacs_server), 0, start_emacs, pce_emacs).
index((emacs_toplevel), 0, start_emacs, pce_emacs).
index((grapher), 1, pce_grapher, pce_grapher).
index((grapher), 2, pce_grapher, pce_grapher).
index((pce_help_file), 2, pce_help_file, pce_help_file).
index((pce_help), 2, pce_help_file, pce_help_file).
index((pce_image_directory), 1, pce_image, pce_image).
index((pce_load_cxx), 1, pce_load_cxx, pce_loadcxx).
index((pce_loop), 2, pce_main, pce_main).
index((pce_loop), 1, pce_main, pce_main).
index((pce_main_loop), 1, pce_main, pce_main).
index((dispatch_for_frames), 1, pce_main, pce_main).
index((manpce), 0, pce_manual, pce_manual).
index((manpce), 1, pce_manual, pce_manual).
index((pce_to_method), 2, pce_meta, pce_meta).
index((isa_class), 2, pce_meta, pce_meta).
index((current_class), 2, pce_meta, pce_meta).
index((to_class_name), 2, pce_meta, pce_meta).
index((pce_library_class), 4, pce_meta, pce_meta).
index((implements), 2, pce_meta, pce_meta).
index((implements), 3, pce_meta, pce_meta).
index((pce_to_pl_type), 2, pce_meta, pce_meta).
index((type_accepts_function), 1, pce_meta, pce_meta).
index((postscript), 2, pce_postscript, pce_postscript).
index((progress_checklist), 3, pce_progress, pce_progress).
index((xref_source), 1, pce_prolog_xref, pce_prolog_xref).
index((xref_called), 3, pce_prolog_xref, pce_prolog_xref).
index((xref_defined), 3, pce_prolog_xref, pce_prolog_xref).
index((xref_definition_line), 2, pce_prolog_xref, pce_prolog_xref).
index((xref_exported), 2, pce_prolog_xref, pce_prolog_xref).
index((xref_module), 2, pce_prolog_xref, pce_prolog_xref).
index((xref_op), 2, pce_prolog_xref, pce_prolog_xref).
index((xref_clean), 1, pce_prolog_xref, pce_prolog_xref).
index((xref_current_source), 1, pce_prolog_xref, pce_prolog_xref).
index((xref_done), 2, pce_prolog_xref, pce_prolog_xref).
index((xref_built_in), 1, pce_prolog_xref, pce_prolog_xref).
index((xref_expand), 2, pce_prolog_xref, pce_prolog_xref).
index((xref_source_file), 3, pce_prolog_xref, pce_prolog_xref).
index((xref_source_file), 4, pce_prolog_xref, pce_prolog_xref).
index((xref_public_list), 4, pce_prolog_xref, pce_prolog_xref).
index((xref_meta), 2, pce_prolog_xref, pce_prolog_xref).
index((xref_hook), 1, pce_prolog_xref, pce_prolog_xref).
index((xref_used_class), 2, pce_prolog_xref, pce_prolog_xref).
index((xref_defined_class), 3, pce_prolog_xref, pce_prolog_xref).
index((prompter), 2, pce_prompter, pce_prompter).
index((regex_emacs_to_advanced), 2, regex_compat, pce_regex_compat).
index((regex_convert_file), 1, regex_compat, pce_regex_compat).
index((regex_main), 0, regex_compat, pce_regex_compat).
index((pce_renew), 1, pce_renew, pce_renew).
index((pce_require), 1, pce_require, pce_require).
index((pce_require), 3, pce_require, pce_require).
index((pce_server), 1, pce_server, pce_server).
index((pce_shell_command), 1, pce_shell, pce_shell).
index((use_class_template), 1, pce_class_template, pce_template).
index((use_class_template), 2, pce_class_template, pce_template).
index((pce_define_type), 2, pce_type, pce_type).
index((get_object), 3, pce_util, pce_util).
index((get_object), 4, pce_util, pce_util).
index((get_object), 5, pce_util, pce_util).
index((get_object), 6, pce_util, pce_util).
index((get_object), 7, pce_util, pce_util).
index((get_object), 8, pce_util, pce_util).
index((send_list), 2, pce_util, pce_util).
index((send_list), 3, pce_util, pce_util).
index((get_chain), 3, pce_util, pce_util).
index((chain_list), 2, pce_util, pce_util).
index((default), 3, pce_util, pce_util).
index((gxref), 0, pce_xref_gui, pce_xref).
index((xref_file_imports), 2, pce_xref_gui, pce_xref).
index((xref_file_exports), 2, pce_xref_gui, pce_xref).
index((pcedraw), 0, pce_draw, pcedraw).
index((pcedraw), 1, pce_draw, pcedraw).
index((save_pcedraw), 1, pce_draw, pcedraw).
index((portray_object), 1, pce_portray_object, portray_object).
index((portray_object), 2, pce_portray_object, portray_object).
index((qcompile_pce), 0, pce_qrecompile, qrecompile).
index((scan_arguments), 2, scan_arguments, scan_arguments).
index((scan_arguments), 3, scan_arguments, scan_arguments).
index((pce_fcompile), 1, sp_fcompile, sp_fcompile).
index((pce_fcompile_boot_files), 0, sp_fcompile, sp_fcompile).
index((pce_fcompile_directory), 1, sp_fcompile, sp_fcompile).
index((pce_frecompile_directory), 1, sp_fcompile, sp_fcompile).
index((pce_fcompile_libraries), 0, sp_fcompile, sp_fcompile).
index((pce_frecompile_libraries), 0, sp_fcompile, sp_fcompile).
index((install_unfocus_hook), 0, stayup_popup, stayup_popup).
index((auto_call), 1, pce_compatibility_layer, swi_compatibility).
index((callable_predicate), 1, pce_compatibility_layer, swi_compatibility).
index((modified_since_last_loaded), 1, pce_compatibility_layer, swi_compatibility).
index((pce_error), 1, pce_compatibility_layer, swi_compatibility).
index((pce_warn), 1, pce_compatibility_layer, swi_compatibility).
index((pce_info), 1, pce_compatibility_layer, swi_compatibility).
index((prolog_help), 0, pui_help, swi_help).
index((prolog_help), 1, pui_help, swi_help).
index((prolog_apropos), 1, pui_help, swi_help).
index((prolog_help_topic), 1, pui_help, swi_help).
index((prolog_explain), 1, pui_help, swi_help).
index((prolog_ide), 1, swi_ide, swi_ide).
index((prolog_edit_preferences), 1, prolog_preferences, swi_preferences).
index((prolog_debug_monitor), 0, pce_debug_monitor, 'swi/pce_debug_monitor').
index((pce_show_profile), 0, pce_profile, 'swi/pce_profile').
